summaryrefslogtreecommitdiff
path: root/src/cpu/translation.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/cpu/translation.hh')
-rw-r--r--src/cpu/translation.hh10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/cpu/translation.hh b/src/cpu/translation.hh
index 4ff75546a..a7372f3ee 100644
--- a/src/cpu/translation.hh
+++ b/src/cpu/translation.hh
@@ -153,14 +153,14 @@ class WholeTranslationState
}
/**
* Check if this request is uncacheable. We only need to check the main
* request because the flags will have been copied here on a split
* translation.
*/
bool
- isUncacheable() const
+ isStrictlyOrdered() const
{
- return mainReq->isUncacheable();
+ return mainReq->isStrictlyOrdered();
}
/**
@@ -153,14 +153,14 @@ class WholeTranslationState
}
/**
- * Check if this request is uncacheable. We only need to check the main
- * request because the flags will have been copied here on a split
- * translation.
+ * Check if this request is strictly ordered device access. We
+ * only need to check the main request because the flags will have
+ * been copied here on a split translation.
*/
bool